# Gora Decentralized Oracle utility libraries

Libraries to support development and debugging of Gora-enabled Algorand
blockchain applications.

For usage details, see: https://github.com/GoraNetwork/developer-quick-start